about summary refs log tree commit diff
path: root/src/ppp/nm-ppp-manager.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/ppp/nm-ppp-manager.c')
-rw-r--r--src/ppp/nm-ppp-manager.c22
1 files changed, 4 insertions, 18 deletions
diff --git a/src/ppp/nm-ppp-manager.c b/src/ppp/nm-ppp-manager.c
index 3708b940..f649e0cb 100644
--- a/src/ppp/nm-ppp-manager.c
+++ b/src/ppp/nm-ppp-manager.c
@@ -1,19 +1,5 @@
-/* NetworkManager -- Network link manager
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- *
+// SPDX-License-Identifier: GPL-2.0+
+/*
  * Copyright (C) 2008 Novell, Inc.
  * Copyright (C) 2008 - 2012 Red Hat, Inc.
  */
@@ -1226,7 +1212,7 @@ _ppp_manager_stop (NMPPPManager *self,
 		/* No PID. There is nothing to kill, however, invoke the callback in
 		 * an idle handler.
 		 *
 		 * Note that we don't register nm_shutdown_wait_obj_register().
 		 * In order for shutdown to work properly, the caller must always
 		 * explicitly cancel the action to go down. With the idle-handler,
 		 * cancelling the handle completes the request. */
@@ -1238,7 +1224,7 @@ _ppp_manager_stop (NMPPPManager *self,
 	 * until the process terminated. We do that, by registering an object
 	 * that delays shutdown. */
 	handle->shutdown_waitobj = g_object_new (G_TYPE_OBJECT, NULL);
-	nm_shutdown_wait_obj_register (handle->shutdown_waitobj, "ppp-manager-wait-kill-pppd");
+	nm_shutdown_wait_obj_register_object (handle->shutdown_waitobj, "ppp-manager-wait-kill-pppd");
 	nm_utils_kill_child_async (nm_steal_int (&priv->pid),
 	                           SIGTERM, LOGD_PPP, "pppd",
 	                           NM_SHUTDOWN_TIMEOUT_MS,
@@ -1226,7 +1212,7 @@ _ppp_manager_stop (NMPPPManager *self,
 		 * an idle handler.
 		 *
-		 * Note that we don't register nm_shutdown_wait_obj_register().
+		 * Note that we don't register nm_shutdown_wait_obj_register_object().
 		 * In order for shutdown to work properly, the caller must always
 		 * explicitly cancel the action to go down. With the idle-handler,